@@ -1,4 +1,3 @@
-/* -*- mode: C; c-file-style: "gnu" -*- */
 /*
  * Copyright (C) 2003 Johan Dahlin <johan@gnome.org>
  *
@@ -21,12 +20,12 @@
 #ifndef __STOCK_ICONS_H__
 #define __STOCK_ICONS_H__
 
-#define JAMBOREE_STOCK_PLAY    "jamboree-play"
-#define JAMBOREE_STOCK_STOP    "jamboree-stop"
-#define JAMBOREE_STOCK_NEXT    "jamboree-next"
-#define JAMBOREE_STOCK_PREV    "jamboree-prev"
-#define JAMBOREE_STOCK_PAUSE   "jamboree-pause"
-#define JAMBOREE_STOCK_SHUFFLE "jamboree-shuffle"
+#define JAMBOREE_STOCK_PLAY          "jamboree-play"
+#define JAMBOREE_STOCK_STOP          "jamboree-stop"
+#define JAMBOREE_STOCK_NEXT          "jamboree-next"
+#define JAMBOREE_STOCK_PREV          "jamboree-prev"
+#define JAMBOREE_STOCK_PAUSE         "jamboree-pause"
+#define JAMBOREE_STOCK_RANDOM        "jamboree-random"
 
 #define JAMBOREE_STOCK_VOLUME_ZERO   "jamboree-volume-zero"
 #define JAMBOREE_STOCK_VOLUME_MIN    "jamboree-volume-min"
