@@ -35,26 +35,31 @@
 #include "stock-icons.h"
 #include "jamboree-marshal.h"
 
-static void     volume_button_class_init    (VolumeButtonClass *klass);
-static void     volume_button_init          (VolumeButton      *button);
-static void     volume_button_finalize      (GObject           *object);
-static gboolean scale_key_press_event_cb    (GtkWidget         *widget,
-					     GdkEventKey       *event,
-					     VolumeButton      *button);
-static void     scale_value_changed_cb      (GtkWidget         *widget,
-					     VolumeButton      *button);
-static gboolean popup_button_press_event_cb (GtkWidget         *widget,
-					     GdkEventButton    *event,
-					     VolumeButton      *button);
-static void     show_scale                  (VolumeButton      *button);
-static void     hide_scale                  (VolumeButton      *button);
-static void     toggled_cb                  (GtkWidget         *widget,
-					     gpointer           user_button);
-static gboolean scroll_event_cb             (GtkWidget         *widget,
-					     GdkEventScroll    *event,
-					     VolumeButton      *button);
-static void     update_image                (VolumeButton      *button,
-					     int                vol);
+
+static void     volume_button_class_init      (VolumeButtonClass *klass);
+static void     volume_button_init            (VolumeButton      *button);
+static void     volume_button_finalize        (GObject           *object);
+static gboolean scale_key_press_event_cb      (GtkWidget         *widget,
+					       GdkEventKey       *event,
+					       VolumeButton      *button);
+static void     scale_value_changed_cb        (GtkWidget         *widget,
+					       VolumeButton      *button);
+static gboolean scale_release_event_cb        (GtkWidget         *widget,
+					       GdkEventButton    *event,
+					       VolumeButton      *button);
+static gboolean popup_button_press_event_cb   (GtkWidget         *widget,
+					       GdkEventButton    *event,
+					       VolumeButton      *button);
+static void     show_scale                    (VolumeButton      *button);
+static void     hide_scale                    (VolumeButton      *button);
+static void     toggled_cb                    (GtkWidget         *widget,
+					       gpointer           user_button);
+static gboolean scroll_event_cb               (GtkWidget         *widget,
+					       GdkEventScroll    *event,
+					       VolumeButton      *button);
+static void     update_image                  (VolumeButton      *button,
+					       int                vol);
+
 
 enum {
   VOLUME_CHANGED,
@@ -114,7 +119,8 @@ volume_button_class_init (VolumeButtonClass *klass)
 static void
 volume_button_init (VolumeButton *button)
 {
-  gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
+  /*gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);*/
+  gtk_button_set_focus_on_click (GTK_BUTTON (button), FALSE);
 
   g_signal_connect (button,
 		    "toggled",
@@ -196,6 +202,20 @@ scale_value_changed_cb (GtkWidget    *widget,
   g_signal_emit (button, signals[VOLUME_CHANGED], 0, vol);
 }
 
+static gboolean
+scale_release_event_cb (GtkWidget      *widget,
+			GdkEventButton *event,
+			VolumeButton   *button)
+{
+  if (button->popup)
+    {
+      hide_scale (button);
+      return TRUE;
+    }
+  
+  return FALSE;
+}
+
 static gboolean
 popup_button_press_event_cb (GtkWidget      *widget,
 			     GdkEventButton *event,
@@ -252,7 +272,7 @@ show_scale (VolumeButton *button)
 		    "button_press_event",
 		    G_CALLBACK (popup_button_press_event_cb),
 		    button);
-  
+
   g_signal_connect (button->scale,
 		    "key_press_event",
 		    G_CALLBACK (scale_key_press_event_cb),
@@ -263,6 +283,11 @@ show_scale (VolumeButton *button)
 		    G_CALLBACK (scale_value_changed_cb),
 		    button);
 
+  g_signal_connect (button->scale,
+		    "button_release_event",
+		    G_CALLBACK (scale_release_event_cb),
+		    button);
+  
   label = gtk_label_new (_("+"));	
   gtk_widget_show (label);
   gtk_box_pack_start (GTK_BOX (box), label, FALSE, TRUE, 0);
@@ -279,10 +304,11 @@ show_scale (VolumeButton *button)
   gdk_window_get_origin (GTK_BUTTON (button)->event_window, &x, &y);
   gdk_drawable_get_size (GTK_BUTTON (button)->event_window, &width, &height);
 
-  req.width = MAX (req.width, width);
-  
+  req.width += 2;
+  req.width = MIN (req.width, width);
+
   x += (width - req.width) / 2;
-  y += height;
+  y += 1 + height;
   
   x = MAX (0, x);
   y = MAX (0, y);
@@ -390,8 +416,14 @@ scroll_event_cb (GtkWidget      *widget,
 static void
 update_image (VolumeButton *button, int vol)
 {
+  GtkIconSize size;
   const char *id;
-
+    
+  if (button->mini)
+    size = GTK_ICON_SIZE_MENU;
+  else
+    size = GTK_ICON_SIZE_LARGE_TOOLBAR;
+  
   if (vol <= 0)
     id = JAMBOREE_STOCK_VOLUME_ZERO;
   else if (vol <= 100 / 3)
@@ -401,7 +433,7 @@ update_image (VolumeButton *button, int vol)
   else
     id = JAMBOREE_STOCK_VOLUME_MAX;
 
-  gtk_image_set_from_stock (GTK_IMAGE (button->image), id, GTK_ICON_SIZE_BUTTON);
+  gtk_image_set_from_stock (GTK_IMAGE (button->image), id, size);
 }
 
 void
@@ -416,3 +448,11 @@ volume_button_set_volume (VolumeButton *button, int vol)
   
   g_signal_emit (button, signals[VOLUME_CHANGED], 0, vol);
 }
+
+void
+volume_button_set_mini (VolumeButton *button, gboolean mini)
+{
+  button->mini = mini;
+
+  update_image (button, button->volume);
+}
